# PumpkinPy 0.4.1
## An all-purpose Python module
### by Spatial Innovations

### Features
* Algorithms
  * Bubble Sort
* Applications
  * Graphical Animations
  * Rubiks Cube Solver
* Color Utilities
  * Color Conversions
* Data Management
* Image Utilities
  * Image Transformations
    * Resize
    * Rotate
    * Crop
    * Flip Left Right
    * Flip Top Bottom
  * Image Filtering
    * Grayscale
    * Gaussian Blur
    * Enhance Color
    * Enhance Contrast
    * Enhance Brightness
    * Enhance Sharpness
    * Blend 2 images
    * Invert
    * Change Color Count
    * Dither
    * Pixelate
  * Image Conversions
    * To PNG
    * To JPG
* Mathematical Functions
  * CheckPrime
    * Check whether or not a number is prime
  * FindFactors
    * Find all the factors of a number
  * FindTotatives
    * Find all the totatives of a number
  * NumTotatives
    * Find the number of totatives of a number
  * MapRange
    * Map a number from one range to another
* Pygame Utilities
  * Backgrounds
    * Ball Background
      * Create a background with multiple colorful balls moving around
  * Elements
    * Button Text
      * Create a button that has text on top of it. It updates according to user actions
    * Text Input
      * Create a text input field in which the user can type whatever they want
    * Slider
      * Create a slider which is updated by user action.
    * Bar Graph
      * Create a bar graph which displays all the given information
    * Color Picker
      * Offers a nice gui for the user to pick their color
    * Checkbox
      * Creates a checkbox with the user can interact with
    * Dropdown
      * A dropdown menu which allows you to select different items
  * Interface
    * Create a <a href="https://blender.org">Blender</a> like interface
* Socket Utilities
  * Helper functions and classes to help with networking in python
* Logic
  * Switch Statements

## Installation
* If you have a version installed already, run this command in a terminal:
  * `pip install --upgrade pumpkinpy`
* If you are installing first time, run this command:
  * `pip install pumpkinpy`

## Changelog
* Version 0.4.1
  * Bpy improvements.

* Version 0.3.9
  * Pygame interface
  * Switcher

* Version 0.3.8
  * Socket networks
  * Color utils

* Version 0.3.7
  * Pygame Color Picker element.

* Version 0.3.6
  * Merged StrawberryPy
  * bpy improvements
  * Bar graph improvements

* Version 0.3.2
  * Pygame Bar Graph

* Version 0.3.1
  * bpy improvements

* Version 0.3.0
  * bpy.props kwargs

* Version 0.2.9
  * bpy improvements

* Version 0.2.8
  * Image dithering
  * bpy improvements

* Version 0.2.7
  * Socket utilities, including networks.
  * pygame backgrounds and sliders
  * Image utilities

* Version 0.1.1
  * Pygame text input
  * Bubble sort algorithm
  * Find factors function
  * Check prime function
